# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.1] - 2026-02-10

### Added
- Add flags for delete, create, update, query

### Changed
- Linting
- Update readme
- Setup the snyk module

### Removed
- Remove circular dependency injenction

## New Contributors
* @ made their first contribution

<!-- generated by git-cliff -->
